aboutsummaryrefslogtreecommitdiff
path: root/google/ads/googleads/v1/resources/domain_category.proto
diff options
context:
space:
mode:
Diffstat (limited to 'google/ads/googleads/v1/resources/domain_category.proto')
-rw-r--r--google/ads/googleads/v1/resources/domain_category.proto4
1 files changed, 2 insertions, 2 deletions
diff --git a/google/ads/googleads/v1/resources/domain_category.proto b/google/ads/googleads/v1/resources/domain_category.proto
index dee0b3cc7..1abb8f65d 100644
--- a/google/ads/googleads/v1/resources/domain_category.proto
+++ b/google/ads/googleads/v1/resources/domain_category.proto
@@ -42,12 +42,12 @@ message DomainCategory {
pattern: "customers/{customer}/domainCategories/{domain_category}"
};
// Immutable. The resource name of the domain category.
// Domain category resource names have the form:
//
// `customers/{customer_id}/domainCategories/{campaign_id}~{category_base64}~{language_code}`
string resource_name = 1 [
- (google.api.field_behavior) = IMMUTABLE,
+ (google.api.field_behavior) = OUTPUT_ONLY,
(google.api.resource_reference) = {
type: "googleads.googleapis.com/DomainCategory"
}
@@ -42,12 +42,12 @@ message DomainCategory {
pattern: "customers/{customer}/domainCategories/{domain_category}"
};
- // Immutable. The resource name of the domain category.
+ // Output only. The resource name of the domain category.
// Domain category resource names have the form:
//